@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2022-06-14 16:52:16
+@LastEditTime: 2022-07-19 10:51:06
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,7 +25,7 @@ class HorseracelampListHandler(ClientBaseHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", -1))
         page_size = int(self.get_param("page_size", 30))
@@ -65,7 +65,7 @@ class SyncPayOrderHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         act_id = self.get_act_id()
         user_id = self.get_user_id()
@@ -142,7 +142,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
@@ -198,7 +198,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         :return PageInfo
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
@@ -237,7 +237,7 @@ class SubmitSkuHandler(ClientBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id"))
@@ -282,7 +282,7 @@ class SelectPrizeOrderHandler(ClientBaseHandler):
         :return
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         login_token = self.get_param("login_token")
