@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-05-19 09:33:57
+@LastEditTime: 2022-07-18 13:51:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,6 +10,7 @@ from operator import truediv
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
+from seven_cloudapp_frame.libs.customize.alipay_helper import AliPayRequest
 from seven_cloudapp_frame.models.shakeshop_base_model import *
 from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
@@ -23,12 +24,12 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
     """
     :description: 创建微信预订单
     """
-    @filter_check_params("user_id,pay_order_no")
+    @filter_check_params("pay_order_no",check_user_code=True)
     def get_async(self):
         """
         :description: 创建微信预订单
         :param pay_order_no:支付单号
-        :param user_id:用户标识
+        :param user_code:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -64,7 +65,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
             ref_params = {}
             invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
-            return self.response_json_success(invoke_result_data.data)
+            return self.response_json_success(self.business_process_executed(invoke_result_data.data,ref_params={}))
         except Exception as ex:
             self.logging_link_error("【创建微信预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
@@ -208,14 +209,14 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
 
 class TiktokVoucherOrderHandler(ClientBaseHandler):
     """
-    :description: 创建抖音预订单
+    :description: 创建抖音预订单（直购模式使用，即在抖音小程序直接吊起支付）
     """
-    @filter_check_params("user_id,pay_order_no")
+    @filter_check_params("pay_order_no",check_user_code=True)
     def get_async(self):
         """
         :description: 创建抖音预订单
         :param pay_order_no:支付单号
-        :param user_id:用户标识
+        :param user_code:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -258,7 +259,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
 
 class TiktokPayNotifyHandler(FrameBaseHandler):
     """
-    :description: 抖音支付异步通知
+    :description: 抖音支付异步通知（直购模式使用，即在抖音小程序直接吊起支付）
     """
     @filter_check_params()
     def post_async(self):
@@ -333,7 +334,7 @@ class TiktokPayNotifyHandler(FrameBaseHandler):
 
 class TiktokRefundNotifyHandler(FrameBaseHandler):
     """
-    :description: 抖音退款异步通知
+    :description: 抖音退款异步通知（直购模式使用，即在抖音小程序直接吊起支付）
     """
     @filter_check_params()
     def post_async(self):
@@ -402,7 +403,7 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
 
 class ShakeshopNotifyHandler(FrameBaseHandler):
     """
-    :description: 抖店异步通知
+    :description: 抖店异步通知（读取抖店订单模式使用，即跳到抖店购买商品）
     """
     def post_async(self):
         """
@@ -416,9 +417,9 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
-        asset_type = invoke_result_data.data["asset_type"] if invoke_result_data.data.__contains__("asset_type") else 3 #资产类型，默认价格档位
-        goods_id = invoke_result_data.data["goods_id"] if invoke_result_data.data.__contains__("goods_id") else "" #商品id
-        sku_id = invoke_result_data.data["sku_id"] if invoke_result_data.data.__contains__("sku_id") else "" #skuid
+        asset_type = invoke_result_data.data["asset_type"] if invoke_result_data.data.__contains__("asset_type") else 3  #资产类型，默认价格档位，
+        goods_id = invoke_result_data.data["goods_id"] if invoke_result_data.data.__contains__("goods_id") else ""  #商品id，当资产类型为价格档位，可不填
+        sku_id = invoke_result_data.data["sku_id"] if invoke_result_data.data.__contains__("sku_id") else ""  #skuid，当资产类型为价格档位，可不填
         reward_order_status_list = invoke_result_data.data["reward_order_status_list"] if invoke_result_data.data.__contains__("reward_order_status_list") else [2]  #订单奖励类型，默认2已支付
         sub_b_type_list = invoke_result_data.data["sub_b_type_list"] if invoke_result_data.data.__contains__("sub_b_type_list") else [] #下单场景，默认全部
         try:
@@ -452,7 +453,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                                 tiktok_goods_id_list = []
                                 if asset_type == 3:
                                     price_base_model = PriceBaseModel(context=self.context)
-                                    price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
+                                    price_gear_dict_list,total = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0)
                                     for price_gear_dict in price_gear_dict_list:
                                         tiktok_goods_id_list.append(price_gear_dict["goods_id"])
                                 else:
@@ -512,7 +513,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                                         user_info_model.update_table("pay_price=pay_price+%s,pay_num=pay_num+%s", "user_id=%s", params=[total_pay_price, total_buy_num, user_info_dict["user_id"]])
                                         asset_base_model = AssetBaseModel(context=self)
                                         for item in third_pay_order_list:
-                                            only_id = str(item.sub_pay_order_no)
+                                            only_id = "shakeshop_" + str(item.sub_pay_order_no)
                                             asset_invoke_result_data = asset_base_model.update_user_asset(user_info_dict["app_id"], user_info_dict["act_id"], 0, user_info_dict["user_id"], user_info_dict["open_id"], user_info_dict["user_nick"], item.asset_type, item.buy_num, item.asset_object_id, 1, "", "", "抖店购买", only_id, self.__class__.__name__, self.request_code, info_json={})
                                             if asset_invoke_result_data.success == True:
                                                 redis_init.lpush(pay_order_cache_key, item.sub_pay_order_no)
@@ -560,4 +561,4 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                 if is_add == True:
                     redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
                     redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
-        return pay_order_no_list,redis_init,pay_order_cache_key
\ No newline at end of file
+        return pay_order_no_list,redis_init,pay_order_cache_key
