@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-07-07 19:09:15
+@LastEditTime: 2022-07-19 10:52:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,7 +25,7 @@ class TaskInfoListHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -65,7 +65,7 @@ class ReceiveRewardHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -110,7 +110,7 @@ class FreeGiftHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -153,7 +153,7 @@ class OneSignHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -195,7 +195,7 @@ class WeeklySignHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -237,7 +237,7 @@ class CumulativeSignHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -280,7 +280,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -296,16 +296,18 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
+        is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False
 
         stat_base_model = StatBaseModel(context=self.context)
-        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"BeInvitedUserCount": 1, "BeInvitedCount": 1})
+        if is_stat == True:
+            stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"BeInvitedUserCount": 1, "BeInvitedCount": 1})
 
         invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.request_code, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-            
-        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"AddBeInvitedUserCount": 1})
-        
+        if is_stat == True:
+            stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"AddBeInvitedUserCount": 1})
+
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -330,7 +332,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -376,7 +378,7 @@ class CollectGoodsHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -417,7 +419,7 @@ class BrowseGoodsHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -458,7 +460,7 @@ class FavorStoreHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -499,7 +501,7 @@ class JoinMemberHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -546,7 +548,7 @@ class BrowseSiteHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
@@ -593,7 +595,7 @@ class ShareHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
