@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-06-17 15:39:58
+@LastEditTime: 2022-07-20 14:16:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,7 +30,7 @@ class LoginHandler(ClientBaseHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         user_nick = self.get_param("user_nick")
         act_id = self.get_act_id()
@@ -63,10 +63,10 @@ class LoginHandler(ClientBaseHandler):
             open_id = invoke_result_data.data["openid"]
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, self.get_remote_ip())
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data.data["user_nick"] = self.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
+        invoke_result_data.data["user_nick"] = CryptographyHelper.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
         if invoke_result_data.data["user_nick_encrypt"]:
             invoke_result_data.data["user_nick"] = CryptographyHelper.base64_decrypt(invoke_result_data.data["user_nick_encrypt"])
         ref_params = {}
@@ -112,7 +112,7 @@ class UpdateUserInfoHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         user_nick = self.get_param("user_nick")
         act_id = self.get_act_id()
@@ -139,7 +139,7 @@ class CheckIsMemberHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         mix_nick = self.get_param("mix_nick")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -166,7 +166,7 @@ class GetCrmIntegralHandler(ClientBaseHandler):
         :return: 店铺会员积分
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         mix_nick = self.get_param("mix_nick")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -200,7 +200,7 @@ class ApplyBlackUnbindHandler(ClientBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         open_id = self.get_param("open_id")
         act_id = self.get_act_id()
         user_id = self.get_user_id()
@@ -228,7 +228,7 @@ class GetUnbindApplyHandler(ClientBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_base_model = UserBaseModel(context=self)
@@ -248,7 +248,7 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_prize_id = int(self.get_param("user_prize_id", 0))
@@ -277,7 +277,7 @@ class GetUserAssetHandler(ClientBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
@@ -300,7 +300,7 @@ class UserAssetListHandler(ClientBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
@@ -326,7 +326,7 @@ class AssetLogListHandler(ClientBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         page_index = int(self.get_param("page_index", 0))
@@ -358,7 +358,7 @@ class GetJoinMemberUrlHandler(ClientBaseHandler):
         :return
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         app_base_model = AppBaseModel(context=self)
@@ -385,7 +385,7 @@ class UserAddressListHandler(ClientBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_base_model = UserBaseModel(context=self)
@@ -412,7 +412,7 @@ class SaveUserAddressHandler(ClientBaseHandler):
         :return: dict
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
         open_id = self.get_param("open_id")
