@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2022-06-29 10:26:44
+@LastEditTime: 2022-07-20 18:10:31
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -75,13 +75,14 @@ class UpdateTelephoneHandler(ClientBaseHandler):
         check_code = self.get_param("check_code")
         modify_date = self.get_now_datetime()
 
-        check_code_re = SevenHelper.redis_init().get("user_" + open_id + "_bind_phone_code")
+        check_code_re = SevenHelper.redis_init().get(f"user_bind_phone_code:{open_id}")
         if check_code_re == None:
             return self.response_json_error("error", "验证码已过期")
-        check_code_re = str(check_code_re, 'utf-8')
         if check_code != check_code_re:
             return self.response_json_error("error", "验证码错误")
-        AppInfoModel(context=self).update_table("app_telephone=%s,modify_date=%s", "app_id=%s", [telephone, modify_date, app_id])
+        app_info_model = AppInfoModel(context=self)
+        app_info_model.update_table("app_telephone=%s,modify_date=%s", "app_id=%s", [telephone, modify_date, app_id])
+        app_info_model.delete_dependency_key(DependencyKey.app_info(app_id))
         return self.response_json_success()
 
 
