@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2022-06-14 14:05:36
+@LastEditTime: 2022-07-21 13:59:22
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
@@ -17,6 +17,11 @@ from seven_cloudapp_frame.models.db_models.saas.saas_custom_model import *
 from seven_cloudapp_frame.models.db_models.marketing.marketing_program_model import *
 from aliyunsdkcore.client import AcsClient
 from aliyunsdkcore.request import CommonRequest
+#从Python SDK导入SMS配置管理模块以及安全认证模块
+from baidubce.bce_client_configuration import BceClientConfiguration
+from baidubce.auth.bce_credentials import BceCredentials
+import baidubce.services.sms.sms_client as sms
+import baidubce.exception as ex
 
 
 class LeftNavigationHandler(ClientBaseHandler):
@@ -32,7 +37,7 @@ class LeftNavigationHandler(ClientBaseHandler):
         app_base_model = AppBaseModel(context=self)
         access_token = self.get_access_token()
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = app_base_model.get_left_navigation(self.get_user_nick(), access_token, app_key, app_secret, self.get_param("app_id"))
+        invoke_result_data = app_base_model.get_left_navigation(self.get_user_nick(), access_token, app_key, app_secret, self.get_app_id())
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -49,7 +54,7 @@ class FriendLinkListHandler(ClientBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        friend_link_model = FriendLinkModel(context=self.context)
+        friend_link_model = FriendLinkModel(context=self)
         friend_link_list = friend_link_model.get_cache_list(where="is_release=1")
         return self.response_json_success(friend_link_list)
 
@@ -58,40 +63,60 @@ class SendSmsHandler(ClientBaseHandler):
     """
     :description: 发送短信
     """
+    @filter_check_params("telephone")
     def get_async(self):
         """
         :description: 发送短信
         :param thelephone：电话号码
+        :param sms_type：短信渠道1-阿里 2-百度
         :return 
         :last_editors: HuangJianYi
         """
         open_id = self.get_open_id()
-        thelephone = self.get_param("thelephone")
-        client = AcsClient('LTAI4FwMYR1FBBui21t7cyh7', 'zyTM5zpYcL8lMXwtDgVoCfHgndoSKi', 'cn-hangzhou')
-
+        telephone = self.get_param("telephone")
+        sms_type = self.get_param_int("sms_type",2)
         result_code = str(random.randint(100000, 999999))
-        request = CommonRequest()
-        request.set_accept_format('json')
-        request.set_domain('dysmsapi.aliyuncs.com')
-        request.set_method('POST')
-        request.set_protocol_type('https')  # https | http
-        request.set_version('2017-05-25')
-        request.set_action_name('SendSms')
+        if sms_type == 1:
+            sms_ali_config = config.get_value("sms_ali_config",{"host":"","ak":"","secret":"","region_id":"","sign_name":"","template_code":""})
+            client = AcsClient(sms_ali_config["ak"], sms_ali_config["secret"], sms_ali_config["region_id"])
+            request = CommonRequest()
+            request.set_accept_format('json')
+            request.set_domain(sms_ali_config["host"])
+            request.set_method('POST')
+            request.set_protocol_type('https')  # https | http
+            request.set_version('2017-05-25')
+            request.set_action_name('SendSms')
 
-        request.add_query_param('RegionId', "cn-hangzhou")
-        request.add_query_param('PhoneNumbers', thelephone)
-        request.add_query_param('SignName', "天志互联")
-        request.add_query_param('TemplateCode', "SMS_193145309")
-        request.add_query_param('TemplateParam', "{\"code\":" + result_code + "}")
+            request.add_query_param('RegionId', sms_ali_config["region_id"])
+            request.add_query_param('PhoneNumbers', telephone)
+            request.add_query_param('SignName', sms_ali_config["sign_name"])
+            request.add_query_param('TemplateCode', sms_ali_config["template_code"])
+            request.add_query_param('TemplateParam', "{\"code\":" + result_code + "}")
+            response = client.do_action(request)
+            result = dict(json.loads(response))
+            result["result_code"] = result_code
+            #记录验证码
+            SevenHelper.redis_init().set(f"user_bind_phone_code:{open_id}", result_code, ex=300)
+            return self.response_json_success()
+        else:
+            #设置SmsClient的Host，Access Key ID和Secret Access Key
+            sms_bce_config = config.get_value("sms_bce_config",{"host":"","ak":"","sk":"","signature_id":"","template_id":""})
+            sms_config = BceClientConfiguration(credentials=BceCredentials(sms_bce_config["ak"], sms_bce_config["sk"]), endpoint=sms_bce_config["host"])
+            #新建SmsClient
+            sms_client = sms.SmsClient(sms_config)
+            try:
+                response = sms_client.send_message(signature_id=sms_bce_config["signature_id"], template_id=sms_bce_config["template_id"], mobile=telephone, content_var_dict={'code': result_code, 'time': '30'})
+                #记录验证码
+                SevenHelper.redis_init().set(f"user_bind_phone_code:{open_id}", result_code, ex=300)
+                return self.response_json_success()
+            except ex.BceHttpClientError as e:
+                if isinstance(e.last_error, ex.BceServerError):
+                    self.logger_error.error(f"发送短信失败。Response:{e.last_error.status_code},code:{e.last_error.code},request_id:{e.last_error.request_id}")
+                else:
+                    self.logger_error.error(f"发送短信失败。Unknown exception:{e}")
+                return self.response_json_error("error","发送失败")
 
-        response = client.do_action(request)
-
-        result = dict(json.loads(response))
-        result["result_code"] = result_code
-        #记录验证码
-        SevenHelper.redis_init().set("user_" + open_id + "_bind_phone_code", result_code, ex=300)
-
-        return self.response_json_success()
+ 
 
 
 class MarketingProgramListHandler(ClientBaseHandler):
