@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2022-04-28 15:03:43
+@LastEditTime: 2022-06-14 14:42:56
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -16,7 +16,6 @@ class PayOrderListHandler(ClientBaseHandler):
     """
     :description: 用户购买订单列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 用户购买订单列表
@@ -35,7 +34,7 @@ class PayOrderListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
@@ -76,7 +75,6 @@ class PrizeOrderListHandler(ClientBaseHandler):
     """
     :description: 用户奖品订单列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 用户奖品订单列表
@@ -99,7 +97,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
@@ -131,9 +129,9 @@ class PrizeOrderListHandler(ClientBaseHandler):
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
+        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
         ref_params = {}
-        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
 
 
@@ -141,14 +139,13 @@ class PrizeRosterListHandler(ClientBaseHandler):
     """
     :description: 用户中奖记录列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 用户中奖记录列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param user_open_id：open_id
         :param nick_name：用户昵称
         :param order_no：订单号
@@ -165,7 +162,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
@@ -213,7 +210,7 @@ class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         prize_order_id = int(self.get_param("prize_order_id", 0))
         seller_remark = self.get_param("seller_remark")
         order_base_model = OrderBaseModel(context=self)
@@ -241,7 +238,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         prize_order_id = int(self.get_param("prize_order_id", 0))
         order_status = int(self.get_param("order_status", 0))
         express_company = self.get_param("express_company")
@@ -268,7 +265,7 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
     """
     :description: 导入奖品订单进行发货
     """
-    @filter_check_params("content,act_id")
+    @filter_check_params("content")
     def post_async(self):
         """
         :description: 导入奖品订单进行发货
@@ -281,7 +278,7 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         content = self.get_param("content")
         content_type = int(self.get_param("content_type", 1))
         ref_head_name = self.get_param("ref_head_name", "小程序订单号")
@@ -307,13 +304,12 @@ class PrizeOrderExportHandler(ClientBaseHandler):
     """
     :description: 导出奖品订单列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 导出奖品订单列表
         :param app_id：应用标识
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_code：用户标识
         :param open_id：open_id
         :param order_no：订单号
         :param nick_name：用户昵称
@@ -329,7 +325,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
@@ -357,13 +353,13 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = []
         if page_size <= 500:
-            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table).data
+            prize_order_list_dict, prize_order_list_total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
         else:
             max_page_size = 100
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table).data
+                list_dict, list_total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table)
                 if len(list_dict) <= 0:
                     break
                 prize_order_list_dict.extend(list_dict)
@@ -418,7 +414,6 @@ class PrizeRosterExportHandler(ClientBaseHandler):
     """
     :description: 导出用户中奖记录列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 导出用户中奖记录列表
@@ -442,7 +437,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id =self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         order_no = self.get_param("order_no")
         user_id = self.get_user_id()
@@ -519,13 +514,12 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
     """
     :description: 淘宝支付订单批量导出
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 淘宝支付订单批量导出
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param user_code：用户标识
         :param user_open_id：open_id
         :param nick_name：用户昵称
         :param pay_date_start：订单支付时间开始
@@ -538,7 +532,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
