@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2022-01-11 10:03:07
+@LastEditTime: 2022-06-13 14:38:54
 @LastEditors: HuangJianYi
 :description: 报表模块
 """
@@ -14,7 +14,6 @@ class StatReportListHandler(ClientBaseHandler):
     """
     :description: 报表数据列表(表格)
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 报表数据列表(表格) 
@@ -27,7 +26,7 @@ class StatReportListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
@@ -52,7 +51,6 @@ class TrendReportListHandler(ClientBaseHandler):
     """
     :description: 报表数据列表(趋势图) 
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 报表数据列表(趋势图) 
@@ -65,7 +63,7 @@ class TrendReportListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
