@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-07-01 11:08:29
+@LastEditTime: 2022-07-20 17:06:10
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -83,7 +83,7 @@ class SevenHelper:
         return RedisExHelper.lpop(queue_name)
 
     @classmethod
-    def redis_acquire_lock(self, lock_name, acquire_time=3, time_out=4):
+    def redis_acquire_lock(self, lock_name, acquire_time=5, time_out=10):
         """
         :description: 创建分布式锁
         :param lock_name：锁定名称
@@ -400,7 +400,7 @@ class SevenHelper:
     @classmethod
     def json_dumps(self, rep_dic):
         """
-        :description: 将字典转化为字符串
+        :description: 对象编码成Json字符串
         :param rep_dic：字典对象
         :return: str
         :last_editors: HuangJianYi
@@ -416,7 +416,7 @@ class SevenHelper:
     @classmethod
     def json_loads(self, rep_str):
         """
-        :description: 将字符串转化为字典
+        :description: 将Json字符串解码成python对象
         :param rep_str：str
         :return: dict
         :last_editors: HuangJianYi
