@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-06-30 13:42:37
+@LastEditTime: 2022-07-15 11:43:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -50,7 +50,7 @@ class AppBaseModel():
         """
         app_info_model = AppInfoModel(context=self.context)
         if is_cache:
-            dependency_key = f"app_info:appid_{app_id}"
+            dependency_key = DependencyKey.app_info(app_id)
             return app_info_model.get_cache_dict(dependency_key=dependency_key, limit="1", where="app_id=%s", params=[app_id])
         else:
             return app_info_model.get_dict(where="app_id=%s", limit="1", params=[app_id])
