@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-06-07 11:10:02
+@LastEditTime: 2022-07-19 14:26:58
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -36,7 +36,7 @@ class CacheModel(BaseModel):
             dependency_key = self.table_name.lower()
         return self.cache_prefix + ":" + "dependency_" + dependency_key
 
-    def get_cache_key(self, prefix_key, field, where='', group_by='', order_by='', limit='', params=None):
+    def get_cache_key(self, prefix_key, field='*', where='', group_by='', order_by='', limit='', params=None):
         """
         :Description: 获取缓存key
         :param prefix_key: 缓存key前缀[entity、entityone、entitylist、entitypagelist、total、dict、dictone、dictlist、dictpagelist]
