@@ -29,7 +29,7 @@ class CmsBaseModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        CmsInfoModel().delete_dependency_key(f"cms_info_list:placeid_{place_id}", delay_delete_time)
+        CmsInfoModel().delete_dependency_key(DependencyKey.cms_info_list(place_id), delay_delete_time)
 
     def save_cms_info(self, place_id, cms_id, app_id, act_id, info_title, simple_title, simple_title_url, info_type, info_summary, info_tag, info_mark, target_url, min_pic, mid_pic, max_pic, info_data, pic_collect_json, sort_index, is_release, i1, i2, i3, i4, s1, s2, s3, s4):
         """
@@ -155,7 +155,7 @@ class CmsBaseModel():
             params.append(app_id)
         cms_info_model = CmsInfoModel(context=self.context)
         if is_cache == True:
-            page_list, total = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"cms_info_list:placeid_{place_id}",cache_expire=600)
+            page_list, total = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.cms_info_list(place_id),cache_expire=600)
         else:
             page_list, total = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
         return page_list, total
