@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-04-29 16:24:33
+@LastEditTime: 2022-07-21 09:33:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,7 +19,7 @@ class AssetConsoleModel():
     """
     :description: 资产控制台业务模型
     """
-    def console_asset_warn(self, mod_count=1):
+    def console_asset(self, mod_count=1):
         """
         :description: 控制台资产预警
         :param mod_count: 单表队列数
@@ -30,41 +30,31 @@ class AssetConsoleModel():
         sub_table_config = sub_table_config_list.get("asset_log_tb", {"sub_count": 0, "sub_ways": 0})
         sub_count = sub_table_config.get("sub_count", 0)
         if sub_count == 0:
-            self._start_process_user_asset_warn(None, mod_count)
+            y = threading.Thread(target=self._process_user_asset_warn, args=[None])
+            y.start()
         else:
             for i in range(sub_count):
-                self._start_process_user_asset_warn(str(i), mod_count)
+                 o = threading.Thread(target=self._process_user_asset_warn, args=[str(i)])
+                 o.start()
 
         for i in range(mod_count):
             j = threading.Thread(target=self._process_asset_inventory_warn, args=[i, mod_count])
             j.start()
 
-        for i in range(10):
-            n = threading.Thread(target=self._process_asset_inventory_queue, args=[i])
-            n.start()
+        n = threading.Thread(target=self._process_asset_inventory_queue, args=[])
+        n.start()
 
-        l = threading.Thread(target=self._process_onlyid_warn, args=[])
-        l.start()
-
-        k = threading.Thread(target=self._push_warn_notice, args=[])
-        k.start()
-
-    def _start_process_user_asset_warn(self, sub_table, mod_count):
-
-        for i in range(mod_count):
-            t = threading.Thread(target=self._process_user_asset_warn, args=[sub_table, i, mod_count])
-            t.start()
-
-    def _process_user_asset_warn(self, sub_table, mod_value, mod_count):
+        t = threading.Thread(target=self._process_asset_intercept_queue, args=[])
+        t.start()
+        
+    def _process_user_asset_warn(self, sub_table):
         """
         :description: 处理用户资产负数预警
         :param sub_table: 分表名称
-        :param mod_value: 当前队列值
-        :param mod_count: 队列数
         :return: 
         :last_editors: HuangJianYi
         """
-        print(f"{TimeHelper.get_now_format_time()} 用户资产负数预警队列{mod_value}启动")
+        print(f"{TimeHelper.get_now_format_time()} 用户资产负数预警启动")
         while True:
             try:
                 time.sleep(0.1)
@@ -72,10 +62,7 @@ class AssetConsoleModel():
                 asset_warn_notice_model = AssetWarnNoticeModel()
                 now_date = TimeHelper.get_now_format_time()
                 now_day_int = SevenHelper.get_now_day_int()
-                if mod_count == 1:
-                    asset_log_list = asset_log_model.get_list(f"now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
-                else:
-                    asset_log_list = asset_log_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
+                asset_log_list = asset_log_model.get_list(f"now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
                 if len(asset_log_list) > 0:
                     for asset_log in asset_log_list:
                         try:
@@ -99,9 +86,12 @@ class AssetConsoleModel():
                             elif asset_log.asset_type == 2:
                                 asset_warn_notice.log_title = "积分异常"
                                 asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
-                            else:
+                            elif asset_log.asset_type == 3:
                                 asset_warn_notice.log_title = f"价格档位异常"
                                 asset_warn_notice.info_desc = f"档位ID:{asset_log.asset_object_id},值为负数:{asset_log.now_value}"
+                            else:
+                                asset_warn_notice.log_title = f"资产类型：{asset_log.asset_type}异常"
+                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
 
                             asset_warn_notice.info_json = SevenHelper.json_dumps(asset_log)
                             asset_warn_notice.create_date = now_date
@@ -109,7 +99,7 @@ class AssetConsoleModel():
                             asset_warn_notice_model.add_entity(asset_warn_notice)
 
                         except Exception as ex:
-                            logger_error.error(f"用户资产负数预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{traceback.format_exc()}")
+                            logger_error.error(f"用户资产负数预警异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{traceback.format_exc()}")
                             continue
                 else:
                     time.sleep(1)
@@ -153,6 +143,7 @@ class AssetConsoleModel():
                     asset_warn_notice = AssetWarnNotice()
                     asset_warn_notice.app_id = hash_value_1["app_id"]
                     asset_warn_notice.act_id = 0
+                    asset_warn_notice.ascription_type = 2
                     asset_warn_notice.handler_name = hash_value_1["handler_name"]
                     asset_warn_notice.request_code =""
                     asset_warn_notice.user_id = ""
@@ -160,7 +151,7 @@ class AssetConsoleModel():
                     asset_warn_notice.user_nick = ""
                     asset_warn_notice.asset_type = 0
                     asset_warn_notice.asset_object_id = ""
-                    asset_warn_notice.log_title = "并发拦截"
+                    asset_warn_notice.log_title = "重复请求拦截"
                     asset_warn_notice.info_desc = f"{date_start}-{date_end}进行了{count}次拦截"
                     asset_warn_notice.info_json = {}
                     asset_warn_notice.create_date = SevenHelper.get_now_datetime()
@@ -182,7 +173,7 @@ class AssetConsoleModel():
                 asset_warn_notice_model = AssetWarnNoticeModel()
                 message_system_db = int(config.get_value("message_system_db",100))
                 redis_init = SevenHelper.redis_init(message_system_db)
-                warn_notice_list = asset_warn_notice_model.get_list("is_notice=0",order_by="create_date asc",limit="50")
+                warn_notice_list = asset_warn_notice_model.get_list("is_notice=0 and ascription_type=1",order_by="create_date asc",limit="50")
                 if len(warn_notice_list) > 0:
                     for warn_notice in warn_notice_list:
                         try:
@@ -249,10 +240,11 @@ class AssetConsoleModel():
                                     asset_warn_notice.log_title = "次数进销存异常"
                                 elif asset_inventory.asset_type == 2:
                                     asset_warn_notice.log_title = "积分进销存异常"
-                                else:
+                                elif asset_inventory.asset_type == 3:
                                     asset_warn_notice.log_title = "价格档位进销存异常"
                                     asset_warn_notice.info_desc = f"档位ID:{asset_inventory.asset_object_id}," + asset_warn_notice.info_desc
-
+                                else:
+                                    asset_warn_notice.log_title = f"资产类型：{asset_inventory.asset_type}异常"
                                 asset_warn_notice.info_json = SevenHelper.json_dumps(asset_inventory)
                                 asset_warn_notice.create_date = now_date
                                 asset_warn_notice.create_day = now_day_int
@@ -266,14 +258,18 @@ class AssetConsoleModel():
             except Exception as ex:
                 time.sleep(5)
 
-    def _process_asset_inventory_queue(self,mod_value):
-
+    def _process_asset_inventory_queue(self):
+        """
+        :description: 处理资产队列入进销存
+        :return: 
+        :last_editors: HuangJianYi
+        """
         while True:
             try:
                 time.sleep(0.1)
                 redis_init = SevenHelper.redis_init()
                 asset_inventory_model = AssetInventoryModel()
-                asset_queue_json = redis_init.lpop(f"asset_queue_list:{mod_value}")
+                asset_queue_json = redis_init.lpop(f"asset_queue_list")
                 if not asset_queue_json:
                     time.sleep(1)
                     continue
@@ -326,10 +322,35 @@ class AssetConsoleModel():
                 except Exception as ex:
                     asset_queue_dict["process_count"] += 1
                     if asset_queue_dict["process_count"] <= 10:
-                        redis_init.rpush(f"asset_queue_list:{mod_value}", SevenHelper.json_dumps(asset_queue_dict))
+                        redis_init.rpush(f"asset_queue_list", SevenHelper.json_dumps(asset_queue_dict))
                     else:
-                        logger_error.error(f"资产队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_queue_dict)},ex:{traceback.format_exc()}")
+                        logger_error.error(f"资产队列异常,json串:{SevenHelper.json_dumps(asset_queue_dict)},ex:{traceback.format_exc()}")
                     continue
             except Exception as ex:
-                logger_error.error(f"资产队列{mod_value}异常,ex:{traceback.format_exc()}")
+                logger_error.error(f"资产队列异常,ex:{traceback.format_exc()}")
+                time.sleep(5)
+
+    def _process_asset_intercept_queue(self):
+        """
+        :description: 处理资产拦截队列入库
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        while True:
+            try:
+                time.sleep(0.1)
+                redis_init = SevenHelper.redis_init()
+                asset_warn_notice_model = AssetWarnNoticeModel()
+                queue_json = redis_init.lpop(f"asset_intercept_queue_list")
+                if not queue_json:
+                    time.sleep(1)
+                    continue
+                try:
+                    queue_dict = SevenHelper.json_loads(queue_json)
+                    asset_warn_notice = SevenHelper.auto_mapper(AssetWarnNotice,queue_dict)
+                    asset_warn_notice_model.add_entity(asset_warn_notice)
+                except Exception as ex:
+                    continue
+            except Exception as ex:
+                logger_error.error(f"资产拦截队列异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
\ No newline at end of file
