@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-06-01 13:43:04
+@LastEditTime: 2022-07-22 16:24:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -174,7 +174,7 @@ class FrameBaseModel():
         
         return SevenHelper.get_sub_table(object_id, sub_table_config.get("sub_count", 0))
         
-    def process_malice_request(self,handler_name,user_id,ip="",user_request_limit_num=30,ip_request_limit_num=30,cycle_type=1,limit_request_time=24):
+    def process_malice_request(self, handler_name, user_id, ip="", user_request_limit_num=30, ip_request_limit_num=30, cycle_type=1, limit_request_time=24):
         """
         :description: 处理恶意请求
         :param handler_name:接口名称
@@ -236,45 +236,16 @@ class FrameBaseModel():
                 redis_init.expire(count_key, 24*60*60)
         return invoke_result_data
     
-    def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1,source_object_id=""):
+    def check_act_info(self, act_id):
         """
-        :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
-        :param app_id:应用标识
+        :description: 检验活动信息
         :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param handler_name:接口名称
-        :param check_new_user:是否新用户才能参与
-        :param check_user_nick:是否校验昵称为空
-        :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒 
-        :param acquire_lock_name:分布式锁名称，为空则不开启分布式锁校验功能
-        :param request_limit_num:请求限制数(指的是当前接口在指定时间内可以请求的次数，用于流量削峰，减少短时间内的大量请求)；0不限制
-        :param request_limit_time:请求限制时间；默认1秒
-        :param source_object_id:来源对象标识
-        :return:
+        :return:invoke_result_data
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-
-        if not act_id or not user_id or not login_token or not handler_name:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "param_error"
-            invoke_result_data.error_message = "参数不能为空或等于0"
-            return invoke_result_data
-
-        #请求太频繁限制
-        if continue_request_expire > 0:
-            continue_request_key = f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}"
-            if source_object_id:
-                continue_request_key += f"_{source_object_id}"
-            if SevenHelper.is_continue_request(continue_request_key, expire=continue_request_expire * 1000) == True:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
-                return invoke_result_data
         act_info_model = ActInfoModel(context=self.context)
-        act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=f"act_info:actid_{act_id}")
+        act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=DependencyKey.act_info(act_id))
         if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_act"
@@ -295,15 +266,26 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "活动已结束"
                 return invoke_result_data
-        act_module_dict = None
-        if module_id > 0:
+        invoke_result_data.data = act_info_dict
+        return invoke_result_data
+
+    def check_act_module(self, module_id):
+        """
+        :description: 检验活动模块
+        :param module_id:活动模块标识
+        :return:invoke_result_data
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if module_id:
             act_module_model = ActModuleModel(context=self.context)
-            act_module_dict = act_module_model.get_cache_dict_by_id(module_id,dependency_key=f"act_module:moduleid_{module_id}")
+            act_module_dict = act_module_model.get_cache_dict_by_id(module_id,dependency_key=DependencyKey.act_module(module_id))
             if not act_module_dict or act_module_dict["is_release"] == 0 or act_module_dict["is_del"] == 1:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "no_module"
                 invoke_result_data.error_message = "活动模块信息不存在"
                 return invoke_result_data
+            now_date = SevenHelper.get_now_datetime()
             act_module_dict["start_date"] = str(act_module_dict["start_date"])
             act_module_dict["end_date"] = str(act_module_dict["end_date"])
             if act_module_dict["start_date"] != "" and act_module_dict["start_date"] != "1900-01-01 00:00:00":
@@ -318,10 +300,25 @@ class FrameBaseModel():
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "活动已结束"
                     return invoke_result_data
-
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_info_dict["id"], "user_id": 0}),context=self.context)
+            invoke_result_data.data = act_module_dict
+        return invoke_result_data
+        
+    def check_user_info(self, app_id, act_id, user_id, login_token, check_new_user, check_user_nick):
+        """
+        :description: 检验用户信息
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param check_new_user:是否新用户才能参与
+        :param check_user_nick:是否校验昵称为空
+        :return:invoke_result_data
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
-        user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=f"user_info:actid_{act_id}_idmd5_{id_md5}")
+        user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=DependencyKey.user_info(act_id,id_md5))
         if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_user"
@@ -353,6 +350,94 @@ class FrameBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "已在另一台设备登录,无法操作"
             return invoke_result_data
+        invoke_result_data.data = user_info_dict
+        return invoke_result_data
+    
+    def check_request_queue(self, request_queue_name, user_id, request_limit_num, request_limit_time):
+        """
+        :description: 检验请求队列,用于流量削峰判断
+        :param request_queue_name:请求队列名称
+        :param user_id:用户标识
+        :param request_limit_num:请求限制数(指的是当前接口在指定时间内可以请求的次数，用于流量削峰，减少短时间内的大量请求)；0不限制
+        :param request_limit_time:请求限制时间；默认1秒
+        :return:invoke_result_data
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if request_limit_num > 0  and request_limit_time > 0:
+            if SevenHelper.redis_check_llen(request_queue_name,request_limit_num) == True:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "concurrent"
+                invoke_result_data.error_message = "当前人气火爆,请稍后再试"
+                return invoke_result_data
+            SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
+        return invoke_result_data
+    
+    def business_process_executing(self, app_id, act_id, module_id, user_id, login_token, handler_name, check_new_user=False, check_user_nick=True, continue_request_expire=5, acquire_lock_name="", request_limit_num=0, request_limit_time=1, source_object_id="",check_act_info=True,check_act_module=True,check_user_info=True):
+        """
+        :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param handler_name:接口名称
+        :param check_new_user:是否新用户才能参与
+        :param check_user_nick:是否校验昵称为空
+        :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒 
+        :param acquire_lock_name:分布式锁名称，为空则不开启分布式锁校验功能
+        :param request_limit_num:请求限制数(指的是当前接口在指定时间内可以请求的次数，用于流量削峰，减少短时间内的大量请求)；0不限制
+        :param request_limit_time:请求限制时间；默认1秒
+        :param source_object_id:来源对象标识
+        :param check_act_info:是否检验活动信息
+        :param check_act_module:是否检验活动模块信息
+        :param check_user_info:是否校验用户信息
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+
+        if not act_id or not user_id or not login_token or not handler_name:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
+            return invoke_result_data
+
+        #请求太频繁限制
+        if continue_request_expire > 0:
+            continue_request_key = f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}"
+            if source_object_id:
+                continue_request_key += f"_{source_object_id}"
+            if SevenHelper.is_continue_request(continue_request_key, expire=continue_request_expire * 1000) == True:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
+                return invoke_result_data
+        #校验活动
+        act_info_dict = None
+        if check_act_info == True:
+            invoke_result_data = self.check_act_info(act_id)
+            if invoke_result_data.success == False:
+                return invoke_result_data
+            act_info_dict = invoke_result_data.data
+            invoke_result_data.data = None
+        #校验活动模块
+        act_module_dict = None
+        if check_act_module == True:
+            invoke_result_data = self.check_act_module(module_id)
+            if invoke_result_data.success == False:
+                return invoke_result_data
+            act_module_dict = invoke_result_data.data
+            invoke_result_data.data = None
+        #校验用户信息
+        user_info_dict = None
+        if check_user_info == True:
+            invoke_result_data = self.check_user_info(app_id,act_id,user_id,login_token,check_new_user,check_user_nick)
+            if invoke_result_data.success == False:
+                return invoke_result_data
+            user_info_dict = invoke_result_data.data
+            invoke_result_data.data = None
+        
         #分布式锁名称存在才进行校验
         identifier = ""
         if acquire_lock_name:
@@ -363,14 +448,11 @@ class FrameBaseModel():
                 invoke_result_data.error_message = "当前人气火爆,请稍后再试"
                 return invoke_result_data
         request_queue_name = ""
-        if request_limit_num > 0  and request_limit_time > 0:
+        if request_limit_num > 0 and request_limit_time > 0:
             request_queue_name = f"request_queue:{handler_name}_{act_id}_{module_id}"
-            if SevenHelper.redis_check_llen(request_queue_name,request_limit_num) == True:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "concurrent"
-                invoke_result_data.error_message = "当前人气火爆,请稍后再试"
+            invoke_result_data = self.check_request_queue(request_queue_name,user_id,request_limit_num,request_limit_time)
+            if invoke_result_data.success == False:
                 return invoke_result_data
-            SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
 
         invoke_result_data.data = {}
         invoke_result_data.data["act_info_dict"] = act_info_dict
@@ -390,7 +472,7 @@ class FrameBaseModel():
         
         return invoke_result_data
 
-    def business_process_executed(self,act_id=0,module_id=0,user_id=0,handler_name="",acquire_lock_name="",identifier="",request_queue_name="",source_object_id=""):
+    def business_process_executed(self, act_id=0, module_id=0, user_id=0, handler_name="", acquire_lock_name="", identifier="", request_queue_name="", source_object_id=""):
         """
         :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法,参数可以不传，默认用business_process_executing方法传递的参数
         :param act_id:活动标识
@@ -430,6 +512,4 @@ class FrameBaseModel():
         if request_queue_name:
             SevenHelper.redis_lpop(request_queue_name)
 
-    
-        
 
