@@ -2,13 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-05-24 16:13:27
+@LastEditTime: 2022-07-20 11:28:03
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.user_base_model import UserBaseModel
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
-from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -16,10 +15,10 @@ from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
-from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_pay_order_model import *
 from seven_cloudapp_frame.models.db_models.user.user_info_model import *
+from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
 
 
 class OrderBaseModel(FrameBaseModel):
@@ -41,12 +40,8 @@ class OrderBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        dependency_key = f"prize_order_list:actid_{act_id}"
-        if user_id:
-            dependency_key += f"_userid_{user_id}"
-        PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
+        PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.prize_order_list(act_id,user_id), delay_delete_time)
         
-
     def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除中奖记录依赖建
@@ -56,12 +51,7 @@ class OrderBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        dependency_key = f"prize_roster_list:actid_{act_id}"
-        if user_id:
-            dependency_key += f"_userid_{user_id}"
-        
-        PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(dependency_key, delay_delete_time)
-
+        PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id), delay_delete_time)
 
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
         """
@@ -95,10 +85,11 @@ class OrderBaseModel(FrameBaseModel):
         if condition:
             where += " AND " + condition
             params_list.extend(params)
-        page_info = PageInfo(page_index, page_size, 0, [])
+        page_list = []
+        total = 0
 
         if not app_id or not act_id:
-            return page_info
+            return page_list, total
         if user_id:
             where += " AND user_id=%s"
             params_list.append(user_id)
@@ -132,10 +123,7 @@ class OrderBaseModel(FrameBaseModel):
             params_list.append(create_date_end)
         prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         if is_cache:
-            dependency_key=f"prize_order_list:actid_{act_id}"
-            if user_id:
-                dependency_key += f"_userid_{user_id}"
-            page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key)
+            page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, DependencyKey.prize_order_list(act_id,user_id))
         else:
             page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         if is_search_roster == True:
@@ -148,8 +136,7 @@ class OrderBaseModel(FrameBaseModel):
                 for i in range(len(page_list)):
                     roster_list = [prize_roster for prize_roster in prize_roster_list_dict if page_list[i]["order_no"] == prize_roster["order_no"]]
                     page_list[i]["roster_list"] = roster_list
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+        return page_list, total
 
     def update_prize_order_status(self,app_id,act_id,prize_order_id,order_status,express_company="",express_no="",prize_roster_sub_table=None):
         """
@@ -247,6 +234,55 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         prize_order_model.update_table("seller_remark=%s,modify_date=%s", "id=%s", [seller_remark, now_datetime, prize_order_id])
         return invoke_result_data
+    
+    def update_prize_order_receive_address(self, app_id, act_id, prize_order_id, province=None, city=None, county=None, street=None, address=None, real_name=None, telephone=None):
+        """
+        :description: 更新用户奖品订单收货地址
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param prize_order_id：奖品订单标识
+        :param province:省
+        :param city:市
+        :param county:区县
+        :param street:街道
+        :param address:地址
+        :param real_name:用户名
+        :param telephone:电话
+        :return: 实体模型InvokeResultData
+        :last_editors: HuangJianYi
+        """
+
+        now_datetime = SevenHelper.get_now_datetime()
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        invoke_result_data = InvokeResultData()
+
+        prize_order = prize_order_model.get_entity_by_id(prize_order_id)
+        if not prize_order:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-1"
+            return invoke_result_data
+        if prize_order.app_id != app_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-2"
+            return invoke_result_data
+        if province != None:
+            prize_order.province = province
+        if city != None:
+            prize_order.city = city
+        if county != None:
+            prize_order.county = county
+        if street != None:
+            prize_order.street = street
+        if address != None:
+            prize_order.address = address
+        if real_name != None:
+            prize_order.real_name = real_name
+        if telephone != None:
+            prize_order.telephone = telephone
+        prize_order_model.update_table("province=%s,city=%s,county=%s,street=%s,address=%s,real_name=%s,telephone=%s,modify_date=%s", "id=%s", [prize_order.province, prize_order.city, prize_order.county, prize_order.street, prize_order.address, prize_order.real_name, prize_order.telephone, now_datetime, prize_order_id])
+        return invoke_result_data
 
     def import_prize_order(self, app_id, act_id, content_type, content, ref_head_name='小程序订单号', prize_roster_sub_table=None):
         """
@@ -339,53 +375,6 @@ class OrderBaseModel(FrameBaseModel):
         invoke_result_data.data = {"total_num": total_num}
         return invoke_result_data
 
-    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
-        """
-        :description: 淘宝用户购买订单列表
-        :param app_id：应用标识
-        :param act_id：活动标识
-        :param user_id：用户唯一标识
-        :param open_id：open_id
-        :param nick_name：用户昵称
-        :param pay_date_start：订单支付时间开始
-        :param pay_date_end：订单支付时间结束
-        :param page_size：页大小
-        :param page_index：页索引
-        :param field：查询字段
-        :param order_by：排序
-        :param condition：条件
-        :param params：参数化数组
-        :return: PageInfo
-        :last_editors: HuangJianYi
-        """
-        where = "app_id=%s and act_id=%s"
-        params_list = [app_id,act_id]
-        if condition:
-            where += " AND " + condition
-            params_list.extend(params)
-        page_info = PageInfo(page_index, page_size, 0, [])
-
-        if not act_id:
-            return page_info
-        if user_id:
-            where += " AND user_id=%s"
-            params_list.append(user_id)
-        if open_id:
-            where += " AND open_id=%s"
-            params_list.append(open_id)
-        if nick_name:
-            where += " AND user_nick=%s"
-            params_list.append(nick_name)
-        if pay_date_start:
-            where += " AND pay_date>=%s"
-            params_list.append(pay_date_start)
-        if pay_date_end:
-            where += " AND pay_date<=%s"
-            params_list.append(pay_date_end)
-        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
-
     def select_prize_order(self,app_id,act_id,user_id,login_token,prize_ids,real_name,telephone,province,city,county,street,address):
         """
         :description: 选择奖品进行下单
@@ -513,7 +502,54 @@ class OrderBaseModel(FrameBaseModel):
         invoke_result_data.data = prize_order.__dict__
         return invoke_result_data
 
-    def _get_pay_order_no_list(self,app_id,user_id):
+    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
+        """
+        :description: 淘宝用户购买订单列表
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户唯一标识
+        :param open_id：open_id
+        :param nick_name：用户昵称
+        :param pay_date_start：订单支付时间开始
+        :param pay_date_end：订单支付时间结束
+        :param page_size：页大小
+        :param page_index：页索引
+        :param field：查询字段
+        :param order_by：排序
+        :param condition：条件
+        :param params：参数化数组
+        :return: PageInfo
+        :last_editors: HuangJianYi
+        """
+        where = "app_id=%s and act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
+        page_info = PageInfo(page_index, page_size, 0, [])
+
+        if not act_id:
+            return page_info
+        if user_id:
+            where += " AND user_id=%s"
+            params_list.append(user_id)
+        if open_id:
+            where += " AND open_id=%s"
+            params_list.append(open_id)
+        if nick_name:
+            where += " AND user_nick=%s"
+            params_list.append(nick_name)
+        if pay_date_start:
+            where += " AND pay_date>=%s"
+            params_list.append(pay_date_start)
+        if pay_date_end:
+            where += " AND pay_date<=%s"
+            params_list.append(pay_date_end)
+        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
+        page_info = PageInfo(page_index, page_size, total, page_list)
+        return page_info
+
+    def _get_tao_pay_order_no_list(self,app_id,user_id):
         """
         :description: 获取已获取奖励的订单子编号列表
         :param app_id:应用标识
@@ -585,7 +621,7 @@ class OrderBaseModel(FrameBaseModel):
                     if invoke_result_data.success == True:
                         order_data = invoke_result_data.data
                 if len(order_data)>0:
-                    pay_order_no_list,redis_init,pay_order_cache_key = self._get_pay_order_no_list(app_id,user_id)
+                    pay_order_no_list,redis_init,pay_order_cache_key = self._get_tao_pay_order_no_list(app_id,user_id)
 
                     goods_ids_list = []
                     #满足奖励条件的订单
@@ -594,7 +630,7 @@ class OrderBaseModel(FrameBaseModel):
                     all_order_list = []
                     if asset_type == 3:
                         price_base_model = PriceBaseModel(context=self.context)
-                        price_gear_dict_list = price_base_model.get_price_gear_list(app_id,act_id,100,0).data
+                        price_gear_dict_list,total = price_base_model.get_price_gear_list(app_id,act_id,100,0)
                         for price_gear_dict in price_gear_dict_list:
                             goods_ids_list.append(price_gear_dict["goods_id"])
                     else:
@@ -807,10 +843,7 @@ class OrderBaseModel(FrameBaseModel):
 
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         if is_cache:
-            dependency_key = f"prize_roster_list:actid_{act_id}"
-            if user_id:
-                dependency_key += f"_userid_{user_id}"
-            page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,dependency_key)
+            page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,DependencyKey.prize_roster_list(act_id,user_id))
         else:
             page_list, total = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         page_info = PageInfo(page_index, page_size, total, page_list)
@@ -900,3 +933,92 @@ class OrderBaseModel(FrameBaseModel):
                     prize_roster_list.append(prize_roster)
 
         return prize_roster_list
+
+    def get_coupon_prize(self, app_id, act_id, user_id, user_prize_id,is_log=False):
+        """
+        :description: 领取淘宝优惠券
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param user_prize_id:用户奖品标识
+        :param is_log:是否记录日志
+        :return 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        app_base_model = AppBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        if not app_info_dict:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="小程序不存在"
+            return invoke_result_data
+        access_token = app_info_dict["access_token"]
+        if access_token == "":
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="未授权请联系客服授权"
+            return invoke_result_data
+        dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
+        frame_base_model = FrameBaseModel(context=self)
+        prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self)
+        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
+        if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品不存在"
+            return invoke_result_data
+        tao_coupon_model = TaoCouponModel(context=self)
+        tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", limit="1", params=[prize_roster_dict["prize_id"]])
+        if not tao_coupon_dict or tao_coupon_dict['right_ename'] == "":
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品不是优惠券,无需领取"
+            return invoke_result_data
+        top_base_model = TopBaseModel(context=self)
+        app_key,app_secret = self.get_app_key_secret()
+        top_invoke_result_data = top_base_model.alibaba_benefit_send(tao_coupon_dict['right_ename'], prize_roster_dict["open_id"], access_token, app_key, app_secret, is_log)
+        if top_invoke_result_data.success == False:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="领取失败"
+            return invoke_result_data
+        resp = top_invoke_result_data.data
+        if resp["alibaba_benefit_send_response"]:
+            if resp["alibaba_benefit_send_response"]["result_success"] == True:
+                prize_roster_model.update_table("prize_status=1", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
+                result = {}
+                result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
+                invoke_result_data.data = result
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
+                prize_roster_model.update_table("prize_status=10", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：优惠券无效或已删除"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_SINGLE_COUPON_COUNT_EXCEED_LIMIT":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：优惠券超过限额"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "USER_PERMISSION_EXCEED_MAX_RIGHT_COUNT_IN_DAY":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：同一张优惠券每天限领取一次"
+                return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_ONE_SELLER_COUNT_EXCEED_LIMIT":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：用户优惠券超出10张限制"
+                return invoke_result_data
+        else:
+            result = resp["sub_msg"] if resp["sub_msg"] else ""
+            if result == "" and resp["result_msg"]:
+                result = resp["result_msg"]
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = f"领取失败:{result}"
+            return invoke_result_data
\ No newline at end of file
