@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-07-07 17:57:42
+@LastEditTime: 2022-07-08 11:50:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -59,7 +59,7 @@ class StatBaseModel(FrameBaseModel):
         else:
             redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
-    def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, key_list_dict):
+    def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, stat_data):
         """
         :description: 添加上报
         :param app_id：应用标识
@@ -67,23 +67,37 @@ class StatBaseModel(FrameBaseModel):
         :param module_id：活动模块标识
         :param user_id：用户标识
         :param open_id：open_id
-        :param key_list_dict:键值对字典
+        :param stat_data:统计数据
         :return:
         :last_editors: HuangJianYi
         """
         stat_queue_list = []
-        for key,value in key_list_dict.items():
-            stat_queue = StatQueue()
-            stat_queue.app_id = app_id
-            stat_queue.act_id = act_id
-            stat_queue.module_id = module_id
-            stat_queue.user_id = user_id
-            stat_queue.open_id = open_id
-            stat_queue.key_name = key
-            stat_queue.key_value = value
-            stat_queue.create_date = SevenHelper.get_now_datetime()
-            stat_queue.process_date = SevenHelper.get_now_datetime()
-            stat_queue_list.append(stat_queue)
+        if isinstance(stat_data,list):
+            for item in stat_data:
+                stat_queue = StatQueue()
+                stat_queue.app_id = app_id
+                stat_queue.act_id = act_id
+                stat_queue.module_id = module_id
+                stat_queue.user_id = user_id
+                stat_queue.open_id = open_id
+                stat_queue.key_name = item["key"]
+                stat_queue.key_value = item["value"]
+                stat_queue.create_date = SevenHelper.get_now_datetime()
+                stat_queue.process_date = SevenHelper.get_now_datetime()
+                stat_queue_list.append(stat_queue)
+        else:
+            for key,value in stat_data.items():
+                stat_queue = StatQueue()
+                stat_queue.app_id = app_id
+                stat_queue.act_id = act_id
+                stat_queue.module_id = module_id
+                stat_queue.user_id = user_id
+                stat_queue.open_id = open_id
+                stat_queue.key_name = key
+                stat_queue.key_value = value
+                stat_queue.create_date = SevenHelper.get_now_datetime()
+                stat_queue.process_date = SevenHelper.get_now_datetime()
+                stat_queue_list.append(stat_queue)
 
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
@@ -390,4 +404,4 @@ class StatBaseModel(FrameBaseModel):
 
         self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
 
-        return invoke_result_data
\ No newline at end of file
+        return invoke_result_data
