@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-05-31 18:05:34
+@LastEditTime: 2022-07-21 11:25:21
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -51,7 +51,7 @@ class TopBaseModel():
 
         # 产品千牛后台GM工具（运营人员模拟登录）
         if app_id:
-            app_info = app_info_model.get_cache_entity(where="app_id=%s", params=app_id)
+            app_info = app_info_model.get_entity(where="app_id=%s", params=app_id)
             if app_info:
                 invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": app_info.store_user_nick, "access_token": app_info.access_token}
                 return invoke_result_data
@@ -71,7 +71,7 @@ class TopBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起,请先授权登录"
             return invoke_result_data
-        app_info = app_info_model.get_cache_entity(where="store_user_nick=%s", params=store_user_nick)
+        app_info = app_info_model.get_entity(where="store_user_nick=%s", params=store_user_nick)
         # 有效时间获取
         invoke_result_data = self.get_dead_date(store_user_nick, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
@@ -940,6 +940,52 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
+    def miniapp_distribution_order_get(self, order_id_list, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 小程序投放-查询小程序投放计划信息
+        :param order_id_list:投放计划的id列表 示例值：[1,2,3]
+        :param access_token:access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappDistributionOrderGetRequest()
+            req.order_id_request = {}
+            req.order_id_request["order_id_list"] = order_id_list
+            resp = req.getResponse(access_token)
+            if is_log:
+                log_info = str(resp) + "【access_token】：" + access_token + "【查询小程序投放计划】"
+                if self.context:
+                    self.context.logging_link_info(log_info)
+                elif self.logging_link_info:
+                    self.logging_link_info(log_info)
+            invoke_result_data.data = resp
+            return invoke_result_data
+
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        invoke_result_data.error_code = "no_power"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+                    if "submsg=" in content:
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = content[len("submsg="):]
+                        return invoke_result_data
+            return invoke_result_data
+    
     def alibaba_benefit_query(self, right_ename,access_token,app_key, app_secret, is_log=False):
         """
         :description: 查询优惠券详情信息
