@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-06-07 09:35:59
+@LastEditTime: 2022-07-22 11:48:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -42,16 +42,6 @@ class UserBaseModel(FrameBaseModel):
             return 0
         return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
 
-    def get_user_black_dependency_key(self, act_id, user_id):
-        """
-        :description: 获取用户黑名单缓存key
-        :param act_id：活动标识
-        :param user_id：用户标识
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        return f"user_black:{act_id}_{user_id}"
-
     def _delete_user_black_cache(self, act_id, user_id, delay_delete_time=0.01):
         """
         :description: 删除用户黑名单缓存
@@ -61,21 +51,7 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        UserBlackModel().delete_dependency_key(self.get_user_black_dependency_key(act_id, user_id),delay_delete_time)
-
-    def get_user_info_dependency_key(self, act_id, id_md5, open_id=""):
-        """
-        :description: 获取用户信息缓存key
-        :param user_info_id：用户信息标识
-        :param id_md5：用户md5标识
-        :param open_id：open_id
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        if id_md5:
-            return f"user_info:actid_{act_id}_idmd5_{id_md5}"
-        else:
-            return f"user_info:actid_{act_id}_openid_{open_id}"
+        UserBlackModel().delete_dependency_key(DependencyKey.user_black(act_id, user_id),delay_delete_time)
 
     def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.01):
         """
@@ -86,7 +62,7 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(self.get_user_info_dependency_key(act_id, id_md5),delay_delete_time)
+        UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.user_info(act_id, id_md5),delay_delete_time)
 
     def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
@@ -103,7 +79,7 @@ class UserBaseModel(FrameBaseModel):
             return user_info_dict
         user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
-        dependency_key = self.get_user_info_dependency_key(act_id, id_md5, open_id)
+        dependency_key = DependencyKey.user_info(act_id, id_md5, open_id)
         if id_md5:
             if is_cache:
                 user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=dependency_key)
@@ -179,7 +155,7 @@ class UserBaseModel(FrameBaseModel):
         top_base_model = TopBaseModel(context=self.context)
         return top_base_model.get_join_member_url(access_token, app_key, app_secret, is_log)
 
-    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id=""):
+    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="",login_ip=""):
         """
         :description: 获取或更新用户信息（主要用于登录）
         :param app_id：应用标识
@@ -188,6 +164,7 @@ class UserBaseModel(FrameBaseModel):
         :param user_nick：昵称
         :param avatar：头像
         :param union_id：union_id
+        :param login_ip：登录ip地址
         :return: 返回用户信息
         :last_editors: HuangJianYi
         """
@@ -221,7 +198,10 @@ class UserBaseModel(FrameBaseModel):
                 user_account.avatar = avatar
                 user_account.user_state = 0
                 user_account.create_date = now_datetime
+                user_account.create_ip = login_ip
                 user_account.modify_date = now_datetime
+                user_account.login_date = now_datetime
+                user_account.login_ip = login_ip
                 user_account.id = user_account_model.add_entity(user_account)
             else:
                 if user_nick and user_account.user_nick != user_nick:
@@ -231,7 +211,9 @@ class UserBaseModel(FrameBaseModel):
                     user_account.avatar = avatar
                 if union_id and user_account.union_id != union_id:
                     user_account.union_id = union_id
-                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar,union_id")
+                user_account.login_date = now_datetime
+                user_account.login_ip = login_ip
+                user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,avatar,union_id,login_date,login_ip")
 
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
@@ -251,7 +233,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.create_date = now_datetime
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
-                user_info_model.add_entity(user_info)
+                user_info.id = user_info_model.add_entity(user_info)
             else:
                 if user_info.app_id != app_id:
                     invoke_result_data.success = False
@@ -269,7 +251,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth,union_id")
-                user_info_model.delete_dependency_key([self.get_user_info_dependency_key(act_id, user_info.id_md5), self.get_user_info_dependency_key(act_id, "", user_info.open_id)])
+                user_info_model.delete_dependency_key([DependencyKey.user_info(act_id, user_info.id_md5), DependencyKey.user_info(act_id, "", user_info.open_id)])
 
         except Exception as ex:
             if self.context:
@@ -507,7 +489,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "账号正常,无需申请解封"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id], dependency_key=self.get_user_black_dependency_key(act_id, user_id))
+        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id], dependency_key=DependencyKey.user_black(act_id, user_id))
         if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -640,7 +622,7 @@ class UserBaseModel(FrameBaseModel):
         params = [act_id, user_id]
         user_black_model = UserBlackModel(context=self.context)
         if is_cache:
-            user_black_dict = user_black_model.get_cache_dict(where=where, limit="1", params=params, dependency_key=self.get_user_black_dependency_key(act_id, user_id))
+            user_black_dict = user_black_model.get_cache_dict(where=where, limit="1", params=params, dependency_key=DependencyKey.user_black(act_id, user_id))
         else:
             user_black_dict = user_black_model.get_dict(where, limit="1", params=params)
         return user_black_dict
@@ -769,15 +751,18 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
+        user_address_list = []
+        if not act_id or not user_id:
+            return user_address_list
         condition = "act_id=%s AND user_id=%s"
         params = [act_id, user_id]
         if app_id:
             condition += " AND app_id=%s"
             params.append(app_id)
-        user_address_list = []
+        
         user_address_model = UserAddressModel(context=self.context)
         if is_cache:
-            user_address_list = user_address_model.get_cache_dict_list(condition, limit="100", params=params, dependency_key=f"user_address_list:actid_{act_id}_userid_{user_id}")
+            user_address_list = user_address_model.get_cache_dict_list(condition, limit="100", params=params, dependency_key=DependencyKey.user_address_list(act_id,user_id))
         else:
             user_address_list = user_address_model.get_dict_list(condition, limit="100", params=params)
 
@@ -866,5 +851,5 @@ class UserBaseModel(FrameBaseModel):
             user_address.is_default = is_default
             user_address.create_date = SevenHelper.get_now_datetime()
             user_address_model.add_entity(user_address)
-        user_address_model.delete_dependency_key(f"user_address_list:actid_{act_id}_userid_{user_id}")
+        user_address_model.delete_dependency_key(DependencyKey.user_address_list(act_id,user_id))
         return invoke_result_data
